@@ -5,7 +5,7 @@
 # Copyright (C) 2002       Masato Taruishi <taru@debian.org>
 # Copyright (C) 2006-2008  Junichi Uekawa <dancer@debian.org>
 # Copyright (C) 2007       Famelis George <famelis@otenet.gr>
-# Copyright (C) 2008-2016  Francesco Poli <invernomuto@paranoici.org>
+# Copyright (C) 2008-2017  Francesco Poli <invernomuto@paranoici.org>
 # Copyright (C) 2009-2010  Ryan Niebur <ryan@debian.org>
 # Copyright (C) 2013       Google Inc
 #
@@ -60,7 +60,7 @@ class AppConfig
       sprintf(_(" -P <priority>    : Pin-Priority value [%s].\n"), @pin_priority),
       _(" -E <title>       : Title of RSS output.\n"),
       _(" -q               : Don't display progress bar.\n"),
-      _(" -C <apt.conf>    : apt.conf file to use.\n"),
+      _(" -C <apt.conf>    : Additional apt.conf file to use.\n"),
       _(" -F               : Automatically pin all buggy packages.\n"),
       _(" -N               : Never automatically pin packages.\n"),
       _(" -y               : Assume that you select yes for all questions.\n"),
@@ -80,6 +80,7 @@ class AppConfig
     @tag = nil
     @stats = ["pending", "forwarded", "pending-fixed", "fixed", "done"]
     # TRANSLATORS: the following six strings refer to a plural quantity of bugs
+    # TRANSLATORS: please note that "Outstanding" means "unresolved", not "exceptional"
     @statmap = [["pending", _("Outstanding")],
                 ["forwarded", _("Forwarded")],
                 ["pending-fixed", _("Pending Upload")],
